# configure-django

A package for configuring Django in non-traditional environments.

![alt text](https://img.shields.io/pypi/v/configure_django.svg)
![alt text](https://img.shields.io/travis/pydanny/configure_django.svg)
![alt text](https://pyup.io/repos/github/pydanny/configure_django/shield.svg)

-   Free software: Apache Software License 2.0

## Features

-   TODO

## Features

-   Usage


## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage) project template.